<?php

namespace App\Enums;

/**
 * 订单分销对象枚举类
 */
enum OrderDistributionObject: int
{
    /**
     * 分销对象：技师
     */
    case TECHNICIAN = 1;

    /**
     * 分销对象：店铺
     */
    case SHOP = 2;

    /**
     * 分销对象：代理商
     */
    case AGENT = 3;

    /**
     * 分销对象：推广员
     */
    case PROMOTER = 4;

    /**
     * 获取对象的显示文本
     *
     * @return string 对象的中文描述
     */
    public function label(): string
    {
        return match($this) {
            self::TECHNICIAN => '技师',
            self::SHOP => '店铺',
            self::AGENT => '代理商',
            self::PROMOTER => '推广员',
        };
    }

    /**
     * 获取对象的整数值
     *
     * @return int 对象值
     */
    public function value(): int
    {
        return $this->value;
    }

    /**
     * 检查当前对象是否与指定对象相同
     *
     * @param self $object 要比较的对象
     * @return bool 如果对象相同返回 true，否则返回 false
     */
    public function is(self $object): bool
    {
        return $this === $object;
    }

    /**
     * 根据整数值创建对应的对象枚举实例
     *
     * @param int $value 对象值
     * @return self|null 返回对应的对象枚举实例，如果值无效则返回 null
     */
    public static function fromValue(int $value): ?self
    {
        return match($value) {
            self::TECHNICIAN->value => self::TECHNICIAN,
            self::SHOP->value => self::SHOP,
            self::AGENT->value => self::AGENT,
            self::PROMOTER->value => self::PROMOTER,
            default => null
        };
    }

    /**
     * 获取所有对象的值数组
     *
     * @return array 包含所有对象值的数组
     */
    public static function values(): array
    {
        return array_column(self::cases(), 'value');
    }

    /**
     * 获取所有对象的键值对数组
     *
     * @return array 对象值作为键，显示文本作为值的关联数组
     */
    public static function all(): array
    {
        return [
            self::TECHNICIAN->value => self::TECHNICIAN->label(),
            self::SHOP->value => self::SHOP->label(),
            self::AGENT->value => self::AGENT->label(),
            self::PROMOTER->value => self::PROMOTER->label(),
        ];
    }
}
