<?php

namespace App\Enums;

/**
 * 服务范围类型枚举类
 */
enum ServiceRangeType: int
{
    /**
     * 范围类型：圆形范围
     */
    case CIRCLE = 1;

    /**
     * 范围类型：多边形范围
     */
    case POLYGON = 2;

    /**
     * 范围类型：行政区划
     */
    case ADMINISTRATIVE = 3;

    /**
     * 获取类型的显示文本
     *
     * @return string 类型的中文描述
     */
    public function label(): string
    {
        return match($this) {
            self::CIRCLE => '圆形范围',
            self::POLYGON => '多边形范围',
            self::ADMINISTRATIVE => '行政区划',
        };
    }

    /**
     * 获取类型的整数值
     *
     * @return int 类型值
     */
    public function value(): int
    {
        return $this->value;
    }

    /**
     * 检查当前类型是否与指定类型相同
     *
     * @param self $type 要比较的类型
     * @return bool 如果类型相同返回 true，否则返回 false
     */
    public function is(self $type): bool
    {
        return $this === $type;
    }

    /**
     * 根据整数值创建对应的类型枚举实例
     *
     * @param int $value 类型值
     * @return self|null 返回对应的类型枚举实例，如果值无效则返回 null
     */
    public static function fromValue(int $value): ?self
    {
        return match($value) {
            self::CIRCLE->value => self::CIRCLE,
            self::POLYGON->value => self::POLYGON,
            self::ADMINISTRATIVE->value => self::ADMINISTRATIVE,
            default => null
        };
    }

    /**
     * 获取所有类型的值数组
     *
     * @return array 包含所有类型值的数组
     */
    public static function values(): array
    {
        return array_column(self::cases(), 'value');
    }

    /**
     * 获取所有类型的键值对数组
     *
     * @return array 类型值作为键，显示文本作为值的关联数组
     */
    public static function all(): array
    {
        return [
            self::CIRCLE->value => self::CIRCLE->label(),
            self::POLYGON->value => self::POLYGON->label(),
            self::ADMINISTRATIVE->value => self::ADMINISTRATIVE->label(),
        ];
    }
}
