<?php

namespace App\Enums;

/**
 * 社交平台枚举类
 */
enum SocialPlatform: int
{
    /**
     * 社交平台：微信
     */
    case WECHAT = 1;

    /**
     * 社交平台：QQ
     */
    case QQ = 2;

    /**
     * 社交平台：微博
     */
    case WEIBO = 3;

    /**
     * 社交平台：抖音
     */
    case DOUYIN = 4;

    /**
     * 社交平台：小红书
     */
    case XIAOHONGSHU = 5;

    /**
     * 获取平台的显示文本
     *
     * @return string 平台的中文描述
     */
    public function label(): string
    {
        return match($this) {
            self::WECHAT => '微信',
            self::QQ => 'QQ',
            self::WEIBO => '微博',
            self::DOUYIN => '抖音',
            self::XIAOHONGSHU => '小红书',
        };
    }

    /**
     * 获取平台的整数值
     *
     * @return int 平台值
     */
    public function value(): int
    {
        return $this->value;
    }

    /**
     * 检查当前平台是否与指定平台相同
     *
     * @param self $platform 要比较的平台
     * @return bool 如果平台相同返回 true，否则返回 false
     */
    public function is(self $platform): bool
    {
        return $this === $platform;
    }

    /**
     * 根据整数值创建对应的平台枚举实例
     *
     * @param int $value 平台值
     * @return self|null 返回对应的平台枚举实例，如果值无效则返回 null
     */
    public static function fromValue(int $value): ?self
    {
        return match($value) {
            self::WECHAT->value => self::WECHAT,
            self::QQ->value => self::QQ,
            self::WEIBO->value => self::WEIBO,
            self::DOUYIN->value => self::DOUYIN,
            self::XIAOHONGSHU->value => self::XIAOHONGSHU,
            default => null
        };
    }

    /**
     * 获取所有平台的值数组
     *
     * @return array 包含所有平台值的数组
     */
    public static function values(): array
    {
        return array_column(self::cases(), 'value');
    }

    /**
     * 获取所有平台的键值对数组
     *
     * @return array 平台值作为键，显示文本作为值的关联数组
     */
    public static function all(): array
    {
        return [
            self::WECHAT->value => self::WECHAT->label(),
            self::QQ->value => self::QQ->label(),
            self::WEIBO->value => self::WEIBO->label(),
            self::DOUYIN->value => self::DOUYIN->label(),
            self::XIAOHONGSHU->value => self::XIAOHONGSHU->label(),
        ];
    }
}
