<?php

namespace App\Enums;

/**
 * 区域类型枚举类
 */
enum SysAreaType: int
{
    /**
     * 区域类型：省
     */
    case PROVINCE = 1;

    /**
     * 区域类型：市
     */
    case CITY = 2;

    /**
     * 区域类型：区
     */
    case DISTRICT = 3;

    /**
     * 获取类型的显示文本
     *
     * @return string 类型的中文描述
     */
    public function label(): string
    {
        return match($this) {
            self::PROVINCE => '省',
            self::CITY => '市',
            self::DISTRICT => '区',
        };
    }

    /**
     * 获取类型的整数值
     *
     * @return int 类型值
     */
    public function value(): int
    {
        return $this->value;
    }

    /**
     * 检查当前类型是否与指定类型相同
     *
     * @param self $type 要比较的类型
     * @return bool 如果类型相同返回 true，否则返回 false
     */
    public function is(self $type): bool
    {
        return $this === $type;
    }

    /**
     * 根据整数值创建对应的类型枚举实例
     *
     * @param int $value 类型值
     * @return self|null 返回对应的类型枚举实例，如果值无效则返回 null
     */
    public static function fromValue(int $value): ?self
    {
        return match($value) {
            self::PROVINCE->value => self::PROVINCE,
            self::CITY->value => self::CITY,
            self::DISTRICT->value => self::DISTRICT,
            default => null
        };
    }

    /**
     * 获取所有类型的值数组
     *
     * @return array 包含所有类型值的数组
     */
    public static function values(): array
    {
        return array_column(self::cases(), 'value');
    }

    /**
     * 获取所有类型的键值对数组
     *
     * @return array 类型值作为键，显示文本作为值的关联数组
     */
    public static function all(): array
    {
        return [
            self::PROVINCE->value => self::PROVINCE->label(),
            self::CITY->value => self::CITY->label(),
            self::DISTRICT->value => self::DISTRICT->label(),
        ];
    }
}
